"""Setup file for python project."""
import os
import requests


def py_init(init, project_path, pname):
    '''
    Setup file creation function.

    Args:
        init: True or False
        project_path: initialize setup.py in project directory

    Returns:
        Initialize successful or not
    '''
    if init:
        # Create README and MANIFEST file
        os.chdir(project_path)
        open('README.md', 'w').close()

        with open('MANIFEST.in', 'w') as mani:
            mani.write('include *.md')
            mani.close()
        print("\n📄 Created README.md & MANIFEST.in ...")

        # fetch .gitignore
        gitig = requests.get(
            'https://raw.githubusercontent.com/github/gitignore/master/Python.gitignore')
        with open('.gitignore', 'wb') as gig:
            for chunk in gitig.iter_content():
                gig.write(chunk)
            gig.close()
        print("\n🚀 Fetched .gitignore from GitHub...")

        # fetch setup.py from PyPa
        setup = requests.get(
            'https://raw.githubusercontent.com/pypa/sampleproject/master/setup.py')
        with open('setup.py', 'wb') as s:
            for chunk in setup.iter_content():
                s.write(chunk)
            s.close()
        print("\n✨ Requested setup.py...")
        return 1
    else:
        print("\nNo setup.py created...")
        return 0



"""Install packages with pip."""
# import os
import subprocess
# import shutil
import shlex


def pip(pkg, project_path, pname):
    '''
    Packages installation function.

    Args:
        pkg: True or False
        project_path: absolute path to the project
        pname: project name

    Returns:
        Packages installed or not installed
    '''
    if pkg:
        pip_path = f"{pname}/bin/pip3"
        # shell_path = os.environ['SHELL']
        # shell = os.path.basename(shell_path)
        # if shell == "bash" or "zsh":
        #     cmd = f"{pname}/bin/activate"
        # elif shell == "csh" or "tcsh":
        #     cmd = f"{pname}/bin/activate.csh"
        # elif shell == "fish":
        #     cmd = f"{pname}/bin/activate.fish"
        # else:
        #     raise OSError("\nUnknown Shell!")
        pkg = input("\n📦 Packages you want to install: ")
        pkgs = shlex.split(pkg)
        args = [pip_path, "install"]
        for i in range(len(args)):
            pkgs.insert(i, args[i])

        # subprocess.run(["source", cmd], shell=True, executable=shell_path)
        # os.chdir(project_path)
        print('\n🔰 Downloading packages...\n')
        subprocess.run(pkgs, check=True)
        return 1
    else:
        print("\nNo package downloaded...")
        return 0
